<?php
/**
 * @version		1.5.1
 * @package		Joomla
 * @subpackage	Edocman
 * @author  Tuan Pham Ngoc
 * @copyright	Copyright (C) 2012 Ossolution Team
 * @license		GNU/GPL, see LICENSE.php
 */

defined('_JEXEC') or die ;
/**
 * EDocman Component Search Model
 *
 * @package		Joomla
 * @subpackage	EDocman
 * @since 1.5
 */
class EDocmanModelSearch extends JModelLegacy
{				
	/**
	 * Documents data array
	 *
	 * @var array
	 */
	var $_data = null;	

	/**
	 * Pagination object
	 *
	 * @var object
	 */
	var $_pagination = null;

	/**
	 * Constructor
	 *
	 * @since 1.5
	 */
	function __construct()
	{
		parent::__construct();

		$mainframe = JFactory::getApplication() ;
		$option    = 'com_edocman' ;	

		// Get the pagination request variables
		$limit		= $mainframe->getUserStateFromRequest( 'global.list.limit', 'limit', $mainframe->getCfg('list_limit'), 'int' );
				
		$limitstart	= $mainframe->getUserStateFromRequest( $option.'.limitstart', 'limitstart', 0, 'int' );

		// In case limit has been changed, adjust limitstart accordingly
		$limitstart = ($limit != 0 ? (floor($limitstart / $limit) * $limit) : 0);

		$this->setState('limit', $limit);
		$this->setState('limitstart', $limitstart);
	}

	/**
	 * Method to get Documents data
	 *
	 * @access public
	 * @return array
	 */
	function getData()
	{
		// Lets load the content if it doesn't already exist
		if (empty($this->_data))
		{
			$query = $this->_buildQuery();			
			$this->_db->setQuery($query);			
			$this->_data = $this->_getList($query, $this->getState('limitstart'), $this->getState('limit'));
			
		}
		
		return $this->_data;
	}	
	/**
	 * Get total Documents 
	 *
	 * @return int
	 */
	function getTotal()
	{
		// Lets load the content if it doesn't already exist
		if (empty($this->_total))
		{
			$where = $this->_buildContentWhere();
			$query = $this->_db->getQuery(true);
			$query->select('COUNT(*)');
			$query->from('#__edocman_documents AS a');
			if ($where) {
				$query->where($where);
			}			
			$this->_db->setQuery($query);						
			$this->_total = $this->_db->loadResult();			
		}		
		
		return $this->_total;
	}
	/**
	 * Method to get a pagination object for the donors
	 *
	 * @access public
	 * @return integer
	 */
	function getPagination()
	{
		// Lets load the content if it doesn't already exist
		if (empty($this->_pagination))
		{
			jimport('joomla.html.pagination');			
			$this->_pagination = new JPagination( $this->getTotal(), $this->getState('limitstart'), $this->getState('limit') );
		}
		
		return $this->_pagination;
	}
	/**
	 * Build the select clause
	 *
	 * @return string
	 */
	function _buildQuery()
	{
		$app = JFactory::getApplication() ;
		$user = JFactory::getUser() ;
		$config = EdocmanHelper::getConfig() ;
		$userId = $user->get('id');
		$db = JFactory::getDbo() ;			
		$query = $db->getQuery(true);
		$where = $this->_buildContentWhere() ;				
		$query->select('a.*') ;
		$query->from('#__edocman_documents AS a');
		$query->leftJoin('#__edocman_document_category AS b ON a.id=b.document_id');
		$query->leftJoin('#__edocman_categories AS c ON b.category_id=c.id');
		
		$query->where($where) ; 				
		$query->order('a.ordering') ;
										
		return $query;		
	}
	
	function _buildContentWhere()
	{
		static $where ;
		if ($where == null) {
			$app = JFactory::getApplication() ;
			$config = EdocmanHelper::getConfig() ;
			$db = JFactory::getDbo() ;
			$user = JFactory::getUser() ;
			$userId = $user->get('id');			
			$categoryId = JRequest::getInt('search_category_id', 0) ;
			$search = JRequest::getVar('search_word', '') ;			
			$where = array() ;
			$where[] = 'a.published = 1' ;			
			$where[] = "((a.user_ids = '' AND a.access IN (".implode(',', $user->getAuthorisedViewLevels()).")) OR a.user_ids='$userId' OR a.user_ids LIKE '$userId,%' OR a.user_ids LIKE '%,$userId,%' OR a.user_ids LIKE '%,$userId')";
			if ($categoryId) {
				$where[] = ' a.id IN (SELECT document_id FROM #__edocman_document_category WHERE category_id = '.$categoryId.' ) ';
			}
			if ($config->activate_multilingual_feature && $app->getLanguageFilter()) {
				$where[] = 'a.language IN (' . $db->Quote(JFactory::getLanguage()->getTag()) . ',' . $db->Quote('*') . ', "")';
			}

			if ($search) {
				$search = $db->quote('%'.$search.'%');
				$where[] = " (a.title LIKE $search OR a.description LIKE $search OR a.short_description LIKE $search OR a.indexed_content LIKE $search OR c.title LIKE $search) " ;
			}
			
			$where 		= ( count( $where ) ? implode( ' AND ', $where ) : '' );
		}
				 
		return $where;
	}	
} 